@@ -36,7 +36,10 @@ class ToTensor(object):
         x = torch.from_numpy(x)
 
         if x.ndim == 2:
-            x = x[:, :, None]
+            if self.permute_dims:
+                x = x[:, :, None]
+            else:
+                x = x[None, :, :]
 
         # Convert HWC->CHW
         if self.permute_dims:
@@ -46,7 +49,7 @@ class ToTensor(object):
 
 
 class ToDtype(object):
-    
+
     def __init__(self, dtype: torch.dtype):
         self.dtype = dtype
 
